# Generated by roxygen2: do not edit by hand

S3method("[",hmrc_tbl)
S3method(as.data.frame,hmrc_tbl)
S3method(format,hmrc_tbl)
S3method(print,hmrc_tbl)
export(clear_cache)
export(get_corporation_tax)
export(get_fuel_duties)
export(get_income_tax_stats)
export(get_property_transactions)
export(get_rd_credits)
export(get_stamp_duty)
export(get_tax_gap)
export(get_tax_receipts)
export(get_tobacco_duties)
export(get_vat)
export(hmrc_cache_info)
export(hmrc_capital_gains)
export(hmrc_clear_cache)
export(hmrc_corporation_tax)
export(hmrc_creative_industries)
export(hmrc_fuel_duties)
export(hmrc_income_tax_stats)
export(hmrc_inheritance_tax)
export(hmrc_list_tax_heads)
export(hmrc_meta)
export(hmrc_patent_box)
export(hmrc_property_transactions)
export(hmrc_publications)
export(hmrc_rd_credits)
export(hmrc_search)
export(hmrc_stamp_duty)
export(hmrc_tax_gap)
export(hmrc_tax_receipts)
export(hmrc_tobacco_duties)
export(hmrc_vat)
export(list_tax_heads)
